<?php

/**

 * Recent posts with thumbnails

 *

 * @package Atframework

 */



class Atframework_Recent_Posts extends WP_Widget {



	public function __construct() {

		$widget_ops = array('classname' => 'widget_recent_posts', 'description' => __( 'Recent posts with thumbnails', 'astrid') );

		parent::__construct('atframework-recent-posts', __('Astrid: Recent Posts', 'astrid'), $widget_ops);

		$this->alt_option_name = 'widget_recent_entries';

	}



	/**

	 * @param array $args

	 * @param array $instance

	 */

	public function widget( $args, $instance ) {

		$cache = array();

		if ( ! $this->is_preview() ) {

			$cache = wp_cache_get( 'widget_recent_posts', 'widget' );

		}



		if ( ! is_array( $cache ) ) {

			$cache = array();

		}



		if ( ! isset( $args['widget_id'] ) ) {

			$args['widget_id'] = $this->id;

		}



		if ( isset( $cache[ $args['widget_id'] ] ) ) {

			echo $cache[ $args['widget_id'] ];

			return;

		}



		ob_start();



		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : '';

		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );



		$number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 5;

		if ( ! $number )

			$number = 5;

		$show_date = isset( $instance['show_date'] ) ? $instance['show_date'] : false;



		$r = new WP_Query( apply_filters( 'astrid_widget_posts_args', array(

			'posts_per_page'      => $number,

			'no_found_rows'       => true,

			'post_status'         => 'publish',

			'ignore_sticky_posts' => true

		) ) );



		if ($r->have_posts()) :

?>

		<?php echo $args['before_widget']; ?>

		<?php if ( $title ) {

			echo $args['before_title'] . $title . $args['after_title'];

		} ?>

		<ul>

		<?php while ( $r->have_posts() ) : $r->the_post(); ?>

			<li class="clearfix">

				<?php if ( has_post_thumbnail() ) : ?>

					<div class="recent-thumb col-md-4">

						<?php the_post_thumbnail('thumbnail'); ?>

					</div>

					<div class="recent-title col-md-8">

				<?php else : ?>

					<div class="recent-title">

				<?php endif; ?>	

				<a href="<?php the_permalink(); ?>"><?php get_the_title() ? the_title() : the_ID(); ?></a>

				<?php if ( $show_date ) : ?>

					<span class="post-date"><i class="fa fa-calendar"></i><?php echo get_the_date(); ?></span>

				<?php endif; ?>

				</div>

			</li>

		<?php endwhile; ?>

		</ul>

		<?php echo $args['after_widget']; ?>

<?php

		wp_reset_postdata();



		endif;



		if ( ! $this->is_preview() ) {

			$cache[ $args['widget_id'] ] = ob_get_flush();

			wp_cache_set( 'widget_recent_posts', $cache, 'widget' );

		} else {

			ob_end_flush();

		}

	}



	public function update( $new_instance, $old_instance ) {

		$instance = $old_instance;

		$instance['title'] = strip_tags($new_instance['title']);

		$instance['number'] = (int) $new_instance['number'];

		$instance['show_date'] = isset( $new_instance['show_date'] ) ? (bool) $new_instance['show_date'] : false;



		$alloptions = wp_cache_get( 'alloptions', 'options' );

		if ( isset($alloptions['widget_recent_entries']) )

			delete_option('widget_recent_entries');



		return $instance;

	}



	/**

	 * @param array $instance

	 */

	public function form( $instance ) {

		$title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';

		$number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;

		$show_date = isset( $instance['show_date'] ) ? (bool) $instance['show_date'] : false;

?>

		<p><label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'astrid' ); ?></label>

		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>" /></p>



		<p><label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number of posts to show:', 'astrid'  ); ?></label>

		<input id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="text" value="<?php echo $number; ?>" size="3" /></p>



		<p><input class="checkbox" type="checkbox" <?php checked( $show_date ); ?> id="<?php echo $this->get_field_id( 'show_date' ); ?>" name="<?php echo $this->get_field_name( 'show_date' ); ?>" />

		<label for="<?php echo $this->get_field_id( 'show_date' ); ?>"><?php _e( 'Display post date?', 'astrid'  ); ?></label></p>

<?php

	}

}