<?php

/**

 * Custom template tags for this theme.

 *

 * Eventually, some of the functionality here could be replaced by core features.

 *

 * @package Astrid

 */



if ( ! function_exists( 'astrid_posted_on' ) ) :

/**

 * Prints HTML with meta information for the current post-date/time and author.

 */

function astrid_posted_on() {

	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {

		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';

	}



	$time_string = sprintf( $time_string,

		esc_attr( get_the_date( 'c' ) ),

		esc_html( get_the_date() ),

		esc_attr( get_the_modified_date( 'c' ) ),

		esc_html( get_the_modified_date() )

	);



	$posted_on = '<i class="fa fa-calendar"></i><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>';



	$byline = sprintf(

		'<i class="fa fa-user"></i>' . esc_html_x( '%s', 'post author', 'astrid' ),

		'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'

	);



	echo '<span class="posted-on">' . $posted_on . '</span><span class="byline"> ' . $byline . '</span>'; // WPCS: XSS OK.



	$categories_list = get_the_category_list( esc_html__( ', ', 'astrid' ) );

	if ( $categories_list ) {

		echo '<span class="cat-links"><i class="fa fa-folder-o"></i>' . $categories_list . '</span>';

	}	



}

endif;



if ( ! function_exists( 'astrid_entry_footer' ) ) :

/**

 * Prints HTML with meta information for the categories, tags and comments.

 */

function astrid_entry_footer() {

	// Hide category and tag text for pages.

	if ( 'post' === get_post_type() ) {



		/* translators: used between list items, there is a space after the comma */

		$tags_list = get_the_tag_list();

		if ( $tags_list ) {

			echo '<span class="tags-links">' . $tags_list . '</span>';

		}

	}



	edit_post_link(

		sprintf(

			/* translators: %s: Name of current post */

			esc_html__( 'Edit %s', 'astrid' ),

			the_title( '<span class="screen-reader-text">"', '"</span>', false )

		),

		'<span class="edit-link">',

		'</span>'

	);

}

endif;

